/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.liferay.geoipusersmap.model;

import com.liferay.geoipusersmap.util.LPortalConnectionPool;
import com.liferay.geoipusersmap.model.UserVO;
import com.liferay.geoipusersmap.model.MarkVO;

import com.liferay.util.portlet.PortletProps;


import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.text.SimpleDateFormat;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;
import java.util.Date;
import java.util.Random;

import com.maxmind.geoip.Location;
import com.maxmind.geoip.LookupService;

/**
 * <a href="GeoIPUsersMapDAO.java.html"><b><i>View Source</i></b></a>
 *
 * @author Jose Miguel Trinchan
 *
 */

public class GeoIPUsersMapDAO {

	//constants
	private static final String _LOCALNET_ADDRESS = "192.168.0.X"; //CHANGE YOUR LOCALNET ADDRESS HERE TO IGNORE THATS ENTRIES
	
	private static final String _GET_USER_DATA = "select userId, screenName, loginIP from User_ where screenName<>'webmaster';";

	public static List<MarkVO> getUsersData() {
		List<MarkVO>  ret = new ArrayList<MarkVO>();
		List<UserVO> userList = new ArrayList<UserVO>();
		Connection con = null;
		PreparedStatement ps = null;
		ResultSet rs = null;
		UserVO user = new UserVO();
		Location location = null;
		LookupService lookupService = null;	
		try {
			lookupService = new LookupService(PortletProps.get("maxmind.database.file"),LookupService.GEOIP_MEMORY_CACHE);
			if (lookupService != null) {			
				con = LPortalConnectionPool.getConnection();
				ps = con.prepareStatement(_GET_USER_DATA);
				rs=ps.executeQuery();
				while (rs.next()) {
					String ip = rs.getString(3);
					if (ip.length()>6) {
						location = lookupService.getLocation(ip);
						user= new UserVO(rs.getInt(1),rs.getString(2),ip, location);
						userList.add(user);
					}
				}
			}
		for (int i=0;i<userList.size();i++) {
			user = (UserVO) userList.get(i);
			boolean encontrado = false;
			int j = 0;
			MarkVO mark = new MarkVO();
			while ((!encontrado)&&(j<ret.size())&&(!GeoIPUsersMapDAO.isLocalIP(user.getIp()))) {
				mark = (MarkVO) ret.get(j);
				j++;
				if (user.isSameLocation(mark)) {
					encontrado=true;
					mark.addScreenname(user.getScreenname());
				}
			}
			if ((!encontrado)&&(!GeoIPUsersMapDAO.isLocalIP(user.getIp()))) {
					location=user.getLocation();
					List list = new ArrayList();
					list.add(user.getScreenname());
					ret.add(new MarkVO(list,location));
			}

			
			
		}
		} catch (Exception e) {e.printStackTrace();}
    
		finally {LPortalConnectionPool.cleanUp(con, ps, rs);}
		
		return ret;
}

	public static Integer getNumUsers() {
		Integer ret = 0; 
		Connection con = null;
		PreparedStatement ps = null;
		ResultSet rs = null;
		String ip = null;
		try {
			con = LPortalConnectionPool.getConnection();
			ps  = con.prepareStatement(_GET_USER_DATA);
			rs = ps.executeQuery();
			while (rs.next()) { 
				ip = rs.getString(3);
				if ((ip!=null)&&(ip!="")&&(ip.length()>7)) {if(!GeoIPUsersMapDAO.isLocalIP(ip)) ret++;}
			}	
		} catch (Exception e) {e.printStackTrace();}
    		
		finally {LPortalConnectionPool.cleanUp(con, ps, rs);}

		return ret;
	}

	public static boolean isLocalIP(String ip) {
		boolean ret = true;
		try{		
			String aux = _LOCALNET_ADDRESS.substring(0,_LOCALNET_ADDRESS.indexOf("X")-1);
			String[] splitedAux = aux.split("\\.");
			
			String[] splitedIP  = ip.split("\\.");

			for (int i=0;i<splitedAux.length;i++) {if (!splitedAux[i].equals(splitedIP[i])) ret=false;}
		} catch (Exception e) {e.printStackTrace();}
		return ret;
	}

}
